# phiflow

Research-oriented differentiable fluid simulation framework

[Project Homepage on GitHub](https://github.com/tum-pbs/PhiFlow)

## Installation

To install phiflow with web interface, run

```
$ pip install phiflow[gui]
```

To run phiflow with custom CUDA operators, you have to install it from source, see the [detailed installation instructions](https://github.com/tum-pbs/PhiFlow/blob/master/documentation/Installation_Instructions.md).